<?php
declare(strict_types=1);

namespace Inti\Filesystem;

use League\Flysystem;
use function getcwd;

/**
 * Class ConfigProvider
 *
 * @package Inti\Filesystem
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-filesystem
 */
final class ConfigProvider
{
    /**
     * @return array
     */
    public function __invoke(): array
    {
        return [
            'filesystems' => [
                'file' => [
                    'adapter' => 'local',
                    'options' => [
                        'location' => getcwd(),
                    ],
                ],
            ],

            'dependencies' => [
                'aliases' => [
                    'FilesystemAdapters' => Adapter\FilesystemAdapterPluginManager::class,
                    Flysystem\FilesystemOperator::class => Flysystem\MountManager::class,
                ],

                'factories' => [
                    Adapter\FilesystemAdapterPluginManager::class => Adapter\FilesystemAdapterPluginManagerFactory::class,
                    Middleware\FilesystemMiddleware::class => Middleware\FilesystemMiddlewareFactory::class,
                    Flysystem\MountManager::class => Service\MountManagerFactory::class,
                ],
            ],
        ];
    }
}
