<?php
declare(strict_types=1);

namespace Inti\Filesystem\Middleware;

use League\Flysystem\FilesystemOperator;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;

/**
 * Class FilesystemMiddleware
 *
 * @package Inti\Filesystem\Middleware
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-filesystem
 */
final class FilesystemMiddleware implements MiddlewareInterface
{
    /** @var FilesystemOperator */
    private $filesystem;

    /**
     * Konstruktor.
     *
     * @param FilesystemOperator $filesystem
     */
    public function __construct(FilesystemOperator $filesystem)
    {
        $this->filesystem = $filesystem;
    }

    /**
     * @param ServerRequestInterface $request
     * @param RequestHandlerInterface $handler
     * @return ResponseInterface
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface
    {
        return $handler->handle(
            $request->withAttribute('filesystem', $this->filesystem)
        );
    }
}
