<?php
declare(strict_types=1);

namespace Inti\Filesystem\Service;

use Laminas\ServiceManager\AbstractPluginManager;
use League\Flysystem\Filesystem;
use League\Flysystem\FilesystemOperator;
use League\Flysystem\MountManager;
use Psr\Container\ContainerInterface;

/**
 * Class FilesystemFactory
 *
 * @package Inti\Filesystem\Service
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-filesystem
 */
final class MountManagerFactory
{
    /**
     * @param ContainerInterface $container
     * @return FilesystemOperator
     */
    public function __invoke(ContainerInterface $container): FilesystemOperator
    {
        $config = $container->get('config');
        /** @var AbstractPluginManager $filesystemAdapters */
        $filesystemAdapters = $container->get('FilesystemAdapters');
        
        foreach (($config['filesystems'] ?? []) as $prefix => $options) {
            $adapter = $filesystemAdapters->get($options['adapter'], $options['options'] ?? []);
            $filesystems[$prefix] = new Filesystem($adapter);
        }

        return new MountManager($filesystems ?? []);
    }
}
